#!/bin/bash

set -o errexit

# Loading common functions
source /opt/kolla/kolla-common.sh

if [[ "${KOLLA_BASE_DISTRO}" == "ubuntu" || \
        "${KOLLA_BASE_DISTRO}" == "debian" ]]; then
    CMD="/usr/sbin/apache2"
    ARGS="-DFOREGROUND"

    # Loading Apache2 ENV variables
    source /etc/apache2/envvars
else
    CMD="/usr/sbin/httpd"
    ARGS="-DFOREGROUND"

    # NOTE(pbourke): httpd will not clean up after itself in some cases which
    # results in the container not being able to restart. Unconfirmed if this
    # happens on Ubuntu. (bug #1489676)
    rm -rf /var/run/httpd/* /run/httpd/* /tmp/httpd*
fi

# Execute config strategy
set_configs

# Bootstrap and exit if KOLLA_BOOTSTRAP variable is set. This catches all cases
# of the KOLLA_BOOTSTRAP variable being set, including empty.
if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
    manage.py syncdb --noinput
    exit 0
fi

exec $CMD $ARGS
