#!/bin/bash

set -e

# for fresh install we need to reset root password 
# and install distributed privileges

if [[ -e /root/.mysql_secret ]]; then

  # get randomly generated password from file
  OLD_PASSWORD=$(grep -Eo '[^ ]+$' /root/.mysql_secret)

  # pre-start mysqld
  echo "+++ pre-start mysqld +++"
  /usr/sbin/mysqld -u mysql --verbose &
  PID=$!
  echo "+++ mysqld PID = $PID +++"

  # wait for server to start
  while mysql 2>&1 | grep "Can't connect" &> /dev/null; do 
    echo "+++ waiting for mysqld to start +++"
    sleep 2; 
  done
  echo "+++ mysqld started (pre-start) +++"

  # check if install already happened before,
  # setting new password will fail if NDB already has
  # distributed privileges.
  if mysql --connect-expired-password \
    -uroot -p$OLD_PASSWORD < /dev/null &> /dev/null; then

    echo "+++ reset root password for new install +++"
    mysql --connect-expired-password \
      -uroot -p$OLD_PASSWORD \
      -e "SET PASSWORD = PASSWORD('$MYSQLCLUSTER_ROOT_PASSWORD');"

    echo "+++ remove test database +++"
    mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD \
      -e "DELETE FROM mysql.db WHERE Db='test' OR Db='test_%';"

    echo "+++ add remote root +++"
    mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD \
      -e "GRANT ALL PRIVILEGES ON *.* TO 'root'@'%' IDENTIFIED BY '$MYSQLCLUSTER_ROOT_PASSWORD' WITH GRANT OPTION;"

    echo "+++ distribute privileges +++"
    mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD < /usr/share/mysql/ndb_dist_priv.sql
  
    mysql -uroot -p$MYSQLCLUSTER_ROOT_PASSWORD -e "CALL mysql.mysql_cluster_move_privileges();"

    echo "+++ delete old secret +++"
    rm /root/.mysql_secret

  else

    echo "+++ database has distributed privileges, skipping +++"
    # TODO: can we reset distributed root password?

  fi

  # stop server
  echo "+++ stopping mysqld PID = $PID (pre-start) +++"
  kill $PID

  # wait for server to stop
  while pkill -0  mysqld ; do 
    echo "+++ waiting for mysqld to stop +++"
    sleep 2; 
  done
  echo "+++ mysqld stopped (pre-start) +++"
fi
